@@ -1,3 +1,4 @@
+import sys
 import time
 
 import gevent
@@ -44,9 +45,35 @@ def spawn_greenlets(conf):
 
 
 def spawn_processes(confs):
-    """Spawn subprocesses with a config similar to spawn_worker."""
+    """Spawn subprocesses with a config similar to spawn_greenlets."""
     processes = []
     for conf in confs:
         p = gipc.start_process(target=conf[0], args=tuple(conf[1:]))
         processes.append(p)
     return processes
+
+
+def never_surrender(fn):
+    """Re-invoke a function if it dies from an exception."""
+    def wrapped(*args, **kwargs):
+        while True:
+            try:
+                fn(*args, **kwargs)
+            except KeyboardInterrupt:
+                break
+            except:
+                print('Error:{}'.format(sys.exc_info()[0]))
+    return wrapped
+
+
+def gen_t(f, scale=1.0, initial_t=0.0):
+    """Turn a f of t into a generator based on wall clock."""
+    t = initial_t
+    last_t = None
+    while True:
+        if last_t is None:
+            last_t = time.time()
+        now = time.time()
+        t += scale * (last_t - now)
+        last_t = now
+        yield f(t)
